==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/representations/GeneralConstObject.h <==
// public class soot.jimple.toolkits.pointer.representations.GeneralConstObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eaf7ad7a888244a0 soot_jimple_toolkits_pointer_representations_ConstantObject
// @dep_class 2d9cb6e2ff57a4cd soot_jimple_toolkits_pointer_representations_GeneralConstObject

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_representations_ConstantObject

#include "soot/jimple/toolkits/pointer/representations/ConstantObject.h"

#ifndef _JC_soot_jimple_toolkits_pointer_representations_GeneralConstObject_H_
#define _JC_soot_jimple_toolkits_pointer_representations_GeneralConstObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$_init$5c04324e81d9c639(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *, struct _jc_soot_Type$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *);
extern jint _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods	soot_jimple_toolkits_pointer_representations_ConstantObject;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods	soot_jimple_toolkits_pointer_representations_GeneralConstObject;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs {
	struct _jc_soot_Type$object	*type;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs {
    _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs	soot_jimple_toolkits_pointer_representations_GeneralConstObject;
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs	soot_jimple_toolkits_pointer_representations_ConstantObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs	soot_jimple_toolkits_pointer_representations_ConstantObject;
    _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs	soot_jimple_toolkits_pointer_representations_GeneralConstObject;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object {
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_representations_GeneralConstObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_representations_GeneralConstObject_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/representations/GeneralConstObject.h <==
// public class soot.jimple.toolkits.pointer.representations.GeneralConstObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eaf7ad7a888244a0 soot_jimple_toolkits_pointer_representations_ConstantObject
// @dep_class 2d9cb6e2ff57a4cd soot_jimple_toolkits_pointer_representations_GeneralConstObject

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_representations_ConstantObject

#include "soot/jimple/toolkits/pointer/representations/ConstantObject.h"

#ifndef _JC_soot_jimple_toolkits_pointer_representations_GeneralConstObject_H_
#define _JC_soot_jimple_toolkits_pointer_representations_GeneralConstObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$_init$5c04324e81d9c639(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *, struct _jc_soot_Type$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods	soot_jimple_toolkits_pointer_representations_ConstantObject;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vmethods	soot_jimple_toolkits_pointer_representations_GeneralConstObject;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs {
	struct _jc_soot_Type$object	*type;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs {
    _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_refs	soot_jimple_toolkits_pointer_representations_GeneralConstObject;
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs	soot_jimple_toolkits_pointer_representations_ConstantObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs	soot_jimple_toolkits_pointer_representations_ConstantObject;
    _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$sub_nonrefs	soot_jimple_toolkits_pointer_representations_GeneralConstObject;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$object {
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$vtype _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_representations_GeneralConstObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_representations_GeneralConstObject$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_representations_GeneralConstObject_H_ */
